@@ -17,11 +17,11 @@ RDF::KV::Patch - Representation of RDF statements to be added or removed
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 SYNOPSIS
 
@@ -332,6 +332,40 @@ sub dont_remove_this {
     my ($s, $p, $o, $g) = _validate(@_);
 }
 
+=head2 graphs_affected
+
+Return the set of graph identifiers affected by the patch, including
+C<undef> for the null graph.
+
+=cut
+
+sub graphs_affected {
+    my $self = shift;
+    my %seen;
+
+    map { $seen{$_} = 1 } (keys %{$self->_pos}, keys %{$self->_neg});
+
+    map { _node($_) } keys %seen;
+}
+
+=head2 subjects_affected
+
+Return the set of subjects that are affected by the patch,
+irrespective of graph.
+
+=cut
+
+sub subjects_affected {
+    my $self = shift;
+    my %seen;
+
+    map {
+        $seen{$_->subject->value} = $_->subject
+    } ($self->to_add, $self->to_remove);
+
+    values %seen;
+}
+
 =head2 to_add
 
 In list context, returns an array of statements to add to the
